@@ -49,6 +49,9 @@ class ProductTemplate:
     image_sets = fields.One2Many(
         'product.product.imageset', 'template', 'Images',
     )
+    default_image_set = fields.Many2One(
+        'product.product.imageset', 'Default Image Set', readonly=True
+    )
 
     def get_products_displayed_on_eshop(self, name=None):
         """
@@ -102,6 +105,9 @@ class Product:
     default_image = fields.Function(
         fields.Many2One('nereid.static.file', 'Image'), 'get_default_image',
     )
+    default_image_set = fields.Many2One(
+        'product.product.imageset', 'Default Image Set', readonly=True,
+    )
     use_template_description = fields.Boolean("Use template's description")
     use_template_images = fields.Boolean("Use template's images")
 
@@ -451,6 +457,32 @@ class ProductsImageSet(ModelSQL, ModelView):
 
         super(ProductsImageSet, cls).__register__(module_name)
 
+    @classmethod
+    def __setup__(cls):
+        super(ProductsImageSet, cls).__setup__()
+        cls._buttons.update({
+            'set_default': {},
+        })
+
+    @classmethod
+    @ModelView.button
+    def set_default(cls, image_sets):
+        """
+        Sets the image set as default image set
+        """
+        Product = Pool().get('product.product')
+        ProductTemplate = Pool().get('product.template')
+
+        for image_set in image_sets:
+            if image_set.product:
+                Product.write([image_set.product], {
+                    'default_image_set': image_set.id,
+                })
+            elif image_set.template:
+                ProductTemplate.write([image_set.template], {
+                    'default_image_set': image_set.id,
+                })
+
 
 class ProductsRelated(ModelSQL):
     "Related Product"
